summaryrefslogtreecommitdiff
path: root/src/map/battle.h
diff options
context:
space:
mode:
authorshennetsind <ind@henn.et>2013-08-22 17:11:00 -0300
committershennetsind <ind@henn.et>2013-08-22 17:11:00 -0300
commit7fc0697a4a53a17941ca40488613f2774bcefa97 (patch)
tree3c8cd0b44361bd033dbc19c9f79446365a02dfc9 /src/map/battle.h
parent0a6066ff2879b59ca2b9249bb96d914254990978 (diff)
downloadhercules-7fc0697a4a53a17941ca40488613f2774bcefa97.tar.gz
hercules-7fc0697a4a53a17941ca40488613f2774bcefa97.tar.bz2
hercules-7fc0697a4a53a17941ca40488613f2774bcefa97.tar.xz
hercules-7fc0697a4a53a17941ca40488613f2774bcefa97.zip
Fixed Bug #7308
Special Thanks to Haruna for the fix, kyeme for the information http://hercules.ws/board/tracker/issue-7308-guild-aura-on-ally/ Closes #78 Signed-off-by: shennetsind <ind@henn.et>
Diffstat (limited to 'src/map/battle.h')
-rw-r--r--src/map/battle.h26
1 files changed, 14 insertions, 12 deletions
diff --git a/src/map/battle.h b/src/map/battle.h
index f52084b41..44f6dd84f 100644
--- a/src/map/battle.h
+++ b/src/map/battle.h
@@ -57,19 +57,21 @@ typedef enum damage_lv {
} damage_lv;
enum e_battle_check_target { //New definitions [Skotlex]
- BCT_NOONE = 0x000000,
- BCT_SELF = 0x010000,
- BCT_ENEMY = 0x020000,
- BCT_PARTY = 0x040000,
- BCT_GUILD = 0x080000,
- BCT_NEUTRAL = 0x100000,
- BCT_SAMEGUILD = 0x200000, // No Guild Allies
-
- BCT_NOGUILD = 0x170000, // This should be (~BCT_GUILD&BCT_ALL)
- BCT_NOPARTY = 0x1b0000, // This should be (~BCT_PARTY&BCT_ALL)
- BCT_NOENEMY = 0x1d0000, // This should be (~BCT_ENEMY&BCT_ALL)
+ BCT_NOONE = 0x000000,
+ BCT_SELF = 0x010000,
+ BCT_ENEMY = 0x020000,
+ BCT_PARTY = 0x040000,
+ BCT_GUILDALLY = 0x080000, // Only allies, NOT guildmates
+ BCT_NEUTRAL = 0x100000,
+ BCT_SAMEGUILD = 0x200000, // No Guild Allies
+
+ BCT_GUILD = 0x280000, // Guild AND allies (BCT_SAMEGUILD|BCT_GUILDALLY)
+
+ BCT_NOGUILD = 0x170000, // This should be (~BCT_GUILD&BCT_ALL)
+ BCT_NOPARTY = 0x3b0000, // This should be (~BCT_PARTY&BCT_ALL)
+ BCT_NOENEMY = 0x3d0000, // This should be (~BCT_ENEMY&BCT_ALL)
- BCT_ALL = 0x1f0000, // Sum of BCT_NOONE to BCT_NEUTRAL
+ BCT_ALL = 0x3f0000, // Sum of BCT_NOONE to BCT_SAMEGUILD
};
/**